@@ -1,7 +1,7 @@
 package T2;
 use Object::Simple(
     base => 'T1',
-    mixin => 'Object::Simple::Mixin::AttrNames'
+    mixins => ['Object::Simple::Mixin::AttrNames']
 );
 
 sub m3 : Attr { default => 'm3' }
